import numpy as np
import matplotlib.pyplot as plt

from astropy.modeling.blackbody import BlackBody1D
from astropy.modeling.models import BlackBody
import astropy.units as u

wavelengths = np.logspace(np.log10(1000), np.log10(3e4), num=1000) * u.AA

# blackbody parameters
temperature = 10000 * u.K

# BlackBody1D is normalized by default to have a bolometric flux of 1
bb1d = BlackBody1D(temperature)

# default results from BlackBody same units as BlackBody1D
bb = BlackBody(temperature)

# plot the results from both methods
fig, ax = plt.subplots(ncols=1, figsize=(4.0, 4.0))

ax.plot(wavelengths, bb1d(wavelengths) / u.sr, label="BlackBody1D", linewidth=6, alpha=0.5)

# divide by bolometric flux to get equivalent of BlackBody1D
ax.plot(wavelengths, bb(wavelengths)/bb.bolometric_flux.value, label="BlackBody")


ax.set_xlabel(r"$\lambda$ [{}]".format(wavelengths.unit))
ax.set_ylabel(r"$Flux$ [{}]".format(bb(wavelengths).unit))
ax.set_xscale("log")
ax.set_yscale("log")
ax.legend(loc="best")

plt.tight_layout()
plt.show()