import numpy as np
import matplotlib.pyplot as plt

from astropy.modeling.models import (
    Box1D,
    Gaussian1D,
    RickerWavelet1D,
    Moffat1D,
    Lorentz1D,
    Sersic1D,
    Trapezoid1D,
    KingProjectedAnalytic1D,
    Voigt1D,
)

x = np.linspace(-4.0, 6.0, num=100)
r = np.logspace(-1.0, 2.0, num=100)

fig, sax = plt.subplots(nrows=3, ncols=3, figsize=(10, 10))
ax = sax.flatten()

mods = [
    Box1D(amplitude=10.0, x_0=1.0, width=1.0),
    Gaussian1D(amplitude=10.0, mean=1.0, stddev=1.0),
    KingProjectedAnalytic1D(amplitude=10.0, r_core=1.0, r_tide=10.0),
    Lorentz1D(amplitude=10.0, x_0=1.0, fwhm=1.0),
    RickerWavelet1D(amplitude=10.0, x_0=1.0, sigma=1.0),
    Moffat1D(amplitude=10.0, x_0=1.0, gamma=1.0, alpha=1.),
    Sersic1D(amplitude=10.0, r_eff=1.0 / 2.0, n=5),
    Trapezoid1D(amplitude=10.0, x_0=1.0, width=1.0, slope=5.0),
    Voigt1D(amplitude_L=10.0, x_0=1.0, fwhm_L=1.0, fwhm_G=1.0),
]

for k, mod in enumerate(mods):
    cname = mod.__class__.__name__
    ax[k].set_title(cname)
    if cname in ["KingProjectedAnalytic1D", "Sersic1D"]:
        ax[k].plot(r, mod(r))
        ax[k].set_xscale("log")
        ax[k].set_yscale("log")
    else:
        ax[k].plot(x, mod(x))

for k in range(len(mods)):
    ax[k].set_xlabel("x")
    ax[k].set_ylabel("y")

# remove axis for any plots not used
for k in range(len(mods), len(ax)):
    ax[k].axis("off")

plt.tight_layout()
plt.show()