import numpy as np
import astropy.units as u
import matplotlib.pyplot as plt
from astropy.timeseries import BoxLeastSquares

np.random.seed(42)
t = np.random.uniform(0, 20, 2000)
y = np.ones_like(t) - 0.1*((t%3)<0.2) + 0.01*np.random.randn(len(t))
model = BoxLeastSquares(t * u.day, y, dy=0.01)
periodogram = model.autopower(0.2, objective="snr")

plt.figure(figsize=(8, 4))
plt.plot(periodogram.period, periodogram.power, "k")
plt.xlabel("period [day]")
plt.ylabel("depth S/N")